@@ -386,11 +386,12 @@ define([
                 var sbDefVariable = new sb.StringBuilder();
                 sbDefVariable.appendFormatLine("<div class='{0} {1}'>", VP_CLASS_STYLE_FLEX_ROW_BETWEEN 
                                                                             , VP_CLASS_STYLE_WIDTH_25PERCENT);
-                if (arg6 == DEF_BLOCK_ARG6_TYPE.ARGS) {
-                    sbDefVariable.appendLine("<span class='vp-apiblock-style-flex-column-center'>*</span>");
-                } else if (arg6 == DEF_BLOCK_ARG6_TYPE.KWARGS) {
-                    sbDefVariable.appendLine("<span class='vp-apiblock-style-flex-column-center'>**</span>");
-                }                                                
+                // Deprecated: don't show this on ui
+                // if (arg6 == DEF_BLOCK_ARG6_TYPE.ARGS) {
+                //     sbDefVariable.appendLine("<span class='vp-apiblock-style-flex-column-center'>*</span>");
+                // } else if (arg6 == DEF_BLOCK_ARG6_TYPE.KWARGS) {
+                //     sbDefVariable.appendLine("<span class='vp-apiblock-style-flex-column-center'>**</span>");
+                // }                                                
                 var suggestInputArg3 =  MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_DEF_ARG_3 + index + uuid
                                                                                     , arg3
                                                                                     , loadedVariableNameList_arg3
