@@ -1,42 +1,35 @@
 define([
     'jquery'
     , 'nbextensions/visualpython/src/common/vpCommon'
-    , 'nbextensions/visualpython/src/common/constant'
+
     , 'nbextensions/visualpython/src/common/StringBuilder'
-    , 'nbextensions/visualpython/src/common/component/vpSuggestInputText'
     , 'nbextensions/visualpython/src/common/component/vpTableLayoutVerticalSimple'
-    , 'nbextensions/visualpython/src/common/component/vpTableLayoutHorizontalSimple'
 
     , '../../api.js'    
 
     , '../../constData.js'
     , '../base/index.js'
 
-], function ( $, vpCommon, vpConst, sb, vpSuggestInputText, vpTableLayoutVerticalSimple, vpTableLayoutHorizontalSimple
+], function ( $, vpCommon, sb, vpTableLayoutVerticalSimple
 
               , api
               , constData
               , baseComponent ) {
 
     const { CreateOneArrayValueAndGet
-        , UpdateOneArrayValueAndGet
-        , DeleteOneArrayValueAndGet
-    
-        , GenerateIfConditionList} = api;
+            , UpdateOneArrayValueAndGet
+            , DeleteOneArrayValueAndGet
+        
+            , GenerateIfConditionList} = api;
 
     const { BLOCK_CODELINE_TYPE
 
             , IF_BLOCK_CONDITION_TYPE
             , IF_BLOCK_SELECT_VALUE_ARG_TYPE
 
-            , STR_COLON_SELECTED
             , STR_EMPTY
-            , STR_FOR
-            , STR_INPUT
-            , STR_SELECTED 
             , STR_DISABLED
             , STR_CLICK
-            , STR_CHANGE
             , STR_CHANGE_KEYUP_PASTE
 
             , STR_VARIABLE
@@ -52,21 +45,6 @@ define([
             , VP_CLASS_STYLE_WIDTH_10PERCENT
             , VP_CLASS_STYLE_WIDTH_15PERCENT
             , VP_CLASS_STYLE_WIDTH_20PERCENT
-            , VP_CLASS_STYLE_WIDTH_25PERCENT
-            , VP_CLASS_STYLE_WIDTH_30PERCENT
-            , VP_CLASS_STYLE_WIDTH_35PERCENT
-            , VP_CLASS_STYLE_WIDTH_40PERCENT
-            , VP_CLASS_STYLE_WIDTH_45PERCENT
-            , VP_CLASS_STYLE_WIDTH_50PERCENT
-            , VP_CLASS_STYLE_WIDTH_55PERCENT
-            , VP_CLASS_STYLE_WIDTH_60PERCENT
-            , VP_CLASS_STYLE_WIDTH_65PERCENT
-            , VP_CLASS_STYLE_WIDTH_70PERCENT
-            , VP_CLASS_STYLE_WIDTH_75PERCENT
-            , VP_CLASS_STYLE_WIDTH_80PERCENT
-            , VP_CLASS_STYLE_WIDTH_85PERCENT
-            , VP_CLASS_STYLE_WIDTH_90PERCENT
-            , VP_CLASS_STYLE_WIDTH_95PERCENT
             , VP_CLASS_STYLE_WIDTH_100PERCENT
 
             , VP_CLASS_STYLE_BGCOLOR_C4C4C4
@@ -133,19 +111,16 @@ define([
                                         ...ifConditionState
                                         , arg1: inputValue
                                     }
-                                    // RenderInputRequiredColor(this);
                                 } else if (i == 2) {
                                     updatedValue = {
                                         ...ifConditionState
                                         , arg2: inputValue 
                                     }
-                                    // RenderInputRequiredColor(this);
                                 } else if (i == 3) {
                                     updatedValue = {
                                         ...ifConditionState
                                         , arg3: inputValue 
                                     }
-                                    // RenderInputRequiredColor(this);
                                 }  else if (i == 4) {
                                     updatedValue = {
                                         ...ifConditionState
@@ -170,7 +145,6 @@ define([
                                         ...ifConditionState
                                         , arg6: inputValue
                                     }
-                                    // RenderInputRequiredColor(this);
                                 }
     
                                 ifConditionListState = UpdateOneArrayValueAndGet(ifConditionListState, index, updatedValue);
@@ -189,8 +163,6 @@ define([
                 /** If USER input 변경 이벤트 함수 바인딩 */
                 $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_USER_INPUT + index + uuid);
                 $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_USER_INPUT + index + uuid, function(event) {
-         
-                    // RenderInputRequiredColor(this);
            
                     var ifConditionListState = thisBlock.getState(STATE_elifConditionList);
                     var ifConditionState = ifConditionListState[index];
@@ -214,8 +186,6 @@ define([
 
                 $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid);
                 $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid, function(event) {
-         
-                    // RenderInputRequiredColor(this);
            
                     var ifConditionListState = thisBlock.getState(STATE_elifConditionList);
                     var ifConditionState = ifConditionListState[index];
@@ -263,7 +233,6 @@ define([
         $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS + uuid), function(event) {
 
             var ifConditionListState = thisBlock.getState(STATE_elifConditionList);
-            thisBlock.addVariableIndex();
             var newCondition = {
                 arg1: ''
                 , arg2: ''
@@ -288,8 +257,6 @@ define([
         $(document).on(STR_CLICK, vpCommon.wrapSelector(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_PLUS_USER_INPUT + uuid), function(event) {
 
             var ifConditionListState = thisBlock.getState(STATE_elifConditionList);
-            thisBlock.addVariableIndex();
-        
             var newCondition = {
                 codeLine: ''
                 , arg6: ''
@@ -315,19 +282,19 @@ define([
                     ...ifConditionState
                     , arg1: selectedValue 
                 }
-                // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_1 + index + uuid, selectedValue);
+               
             } else if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG2) {
                 updatedValue = {
                     ...ifConditionState
                     , arg2: selectedValue 
                 }
-                // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid, selectedValue);
+               
             } else if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3) {
                 updatedValue = {
                     ...ifConditionState
                     , arg3: selectedValue 
                 }
-                // RenderSelectRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid, selectedValue);
+                
             } else if (type == IF_BLOCK_SELECT_VALUE_ARG_TYPE.ARG4) {
                 updatedValue = {
                     ...ifConditionState
@@ -529,8 +496,7 @@ define([
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid).val(arg3);
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).val(arg4);
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).val(arg5);
-                // var isArg5Disabled = false;   
-                // isArg5Disabled = true;
+             
                 if (arg4 == 'none' || arg4 == STR_EMPTY) {
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_4 + index + uuid).addClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).attr(STR_DISABLED, true);
@@ -541,22 +507,13 @@ define([
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_5 + index + uuid).removeClass(VP_CLASS_STYLE_BGCOLOR_C4C4C4);
                 }     
 
-                /** arg6 isDisabled 체크 */
-                // var isArg6Disabled = false;
-                // isArg6Disabled = true;
                 if ( ifConditionListState.length -1 == index ) {
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid).addClass(VP_CLASS_STYLE_OPACITY_0);
                 } else {
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid).val(arg6);
                     $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid).addClass(VP_CLASS_STYLE_OPACITY_1);
                 }
-      
-                // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_1 + index + uuid);
-                // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_2 + index + uuid);
-                // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_3 + index + uuid);
-                // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_ARG_6 + index + uuid);
-
-                // RenderInputRequiredColor(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_IF_USER_INPUT + index + uuid);
+    
             });
 
             return optionContainerDom;
