@@ -17,13 +17,13 @@ define([
         , IF: 3
 
         , TRY: 8
+        , RETURN: 9
     
         , CONTINUE: 11
         , BREAK: 10
         , PASS: 12
-        , RETURN: 9
 
-        , IMPORT: 6
+        // , IMPORT: 6  // import 블럭 삭제 210429
         , LAMBDA: 14
         
         , CODE: 999
@@ -38,7 +38,7 @@ define([
         , IF: 3
         , FOR: 4
         , WHILE: 5
-        , IMPORT: 6
+        // , IMPORT: 6
         , API: 7
         , TRY: 8
 
@@ -67,6 +67,7 @@ define([
         , SHADOW: 1000
 
         , NODE: 100000
+        , NONE: 0
     }
     
     const BLOCK_DIRECTION  = {
@@ -213,11 +214,11 @@ define([
     const NUM_BLOCK_MAX_WIDTH = 360;
     const NUM_APIBLOCK_MAIN_PAGE_WIDTH = 1000;
     const NUM_APIBLOCK_LEFT_PAGE_WIDTH = 140;
-    const NUM_OPTION_PAGE_WIDTH = 225;
+    const NUM_OPTION_PAGE_WIDTH = 335;
 
     const NUM_BUTTONS_PAGE_WIDTH = 200;
-    const NUM_API_BOARD_CENTER_PAGE_WIDTH = 282;
-    const NUM_API_BOARD_CENTER_PAGE_MIN_WIDTH = 282;
+    const NUM_API_BOARD_CENTER_PAGE_WIDTH = 265; //282;
+    const NUM_API_BOARD_CENTER_PAGE_MIN_WIDTH = 265; //282;
     const NUM_TEXT_BLOCK_WIDTH = 900;
     /** ---------------------------------------- const String ------------------------------------------ */
     const STR_EMPTY = '';
@@ -297,6 +298,7 @@ define([
     const STR_INPUT = 'input';
     const STR_FOCUS = 'focus';
     const STR_BLUR = 'blur';
+    const STR_RIGHT_CLICK = 'contextmenu';
     const STR_CHECKED = 'checked';
     const STR_SCROLL = 'scroll';
     const STR_MAX_WIDTH = 'max-width';
@@ -346,6 +348,11 @@ define([
     const VP_ID_APIBLOCK_CLOSE = 'vp_apiblock_close';
     const VP_ID_APIBLOCK_LEFT_TAB_API = 'vp_apiblock_left_tab_api';
 
+    const VP_ID_APIBLOCK_MENU_BOX = 'vp_apiblock_menubox';
+    const VP_ID_APIBLOCK_MENU_RUN = 'vp_apiblock_menu_run';
+    const VP_ID_APIBLOCK_MENU_DUPLICATE = 'vp_apiblock_menu_duplicate';
+    const VP_ID_APIBLOCK_MENU_DELETE = 'vp_apiblock_menu_delete';
+
     const VP_ID_APIBLOCK_OPTION_CODE_ARG = 'vp_apiblockCodeOptionInput';
 
     const VP_ID_APIBLOCK_OPTION_DEF_ARG_3 = 'vp_ApiblockDefArg3';
@@ -418,6 +425,11 @@ define([
     const VP_ID_APIBLOCK_NODE_BLOCK_PLUS_BUTTON = 'vp_apiblock_board_node_plus_button';
     const VP_ID_APIBLOCK_TEXT_BLOCK_PLUS_BUTTON = 'vp_apiblock_board_text_plus_button';
     const VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT = 'vp_apiblock_board_makenode_input';
+    const VP_ID_APIBLOCK_BOARD_MAKE_NODE_PATH = 'vp_apiblock_board_makenode_path';
+
+    const VP_APIBLOCK_BOARD_OPTION_PREVIEW_BUTTON = 'vp_apiblock_board_option_preview_button';
+    const VP_APIBLOCK_BOARD_OPTION_CANCEL_BUTTON = 'vp_apiblock_board_option_cancel_button';
+    const VP_APIBLOCK_BOARD_OPTION_APPLY_BUTTON = 'vp_apiblock_board_option_apply_button';
 
     /** ---------------------------------------- const CSS class String ------------------------------------------ */
     const VP_CLASS_PREFIX = '.';
@@ -440,6 +452,9 @@ define([
     const VP_CLASS_APIBLOCK_ARROW_DOWN = 'vp-apiblock-arrow-down';
     const VP_CLASS_APIBLOCK_OPTION_INPUT_REQUIRED = 'vp-apiblock-option-input-required';
 
+    const VP_CLASS_APIBLOCK_MENU_BOX = 'vp-apiblock-menu-box';
+    const VP_CLASS_APIBLOCK_MENU_ITEM = 'vp-apiblock-menu-item';
+
     const VP_CLASS_BLOCK_BOTTOM_HOLDER = 'vp-block-bottom-holder';
 
     const VP_CLASS_BLOCK_CODETYPE_NAME = 'vp-block-name';
@@ -858,6 +873,7 @@ define([
         , STR_FOCUS
         , STR_BLUR
         , STR_INPUT
+        , STR_RIGHT_CLICK
 
         , STR_FONT_WEIGHT
         , STR_MAX_WIDTH
@@ -912,6 +928,11 @@ define([
         , VP_ID_APIBLOCK_CLOSE
         , VP_ID_APIBLOCK_LEFT_TAB_API
 
+        , VP_ID_APIBLOCK_MENU_BOX
+        , VP_ID_APIBLOCK_MENU_RUN
+        , VP_ID_APIBLOCK_MENU_DUPLICATE
+        , VP_ID_APIBLOCK_MENU_DELETE
+
         , VP_ID_APIBLOCK_OPTION_CODE_ARG
 
         , VP_ID_APIBLOCK_OPTION_DEF_ARG_3
@@ -982,6 +1003,11 @@ define([
         , VP_ID_APIBLOCK_NODE_BLOCK_PLUS_BUTTON
         , VP_ID_APIBLOCK_TEXT_BLOCK_PLUS_BUTTON
         , VP_ID_APIBLOCK_BOARD_MAKE_NODE_BLOCK_INPUT
+        , VP_ID_APIBLOCK_BOARD_MAKE_NODE_PATH
+
+        , VP_APIBLOCK_BOARD_OPTION_PREVIEW_BUTTON
+        , VP_APIBLOCK_BOARD_OPTION_CANCEL_BUTTON
+        , VP_APIBLOCK_BOARD_OPTION_APPLY_BUTTON
 
         , VP_CLASS_PREFIX
 
@@ -1024,6 +1050,9 @@ define([
         , VP_CLASS_APIBLOCK_BLOCK_HEADER
         , VP_CLASS_SELECTED_SHADOWBLOCK
 
+        , VP_CLASS_APIBLOCK_MENU_BOX
+        , VP_CLASS_APIBLOCK_MENU_ITEM
+
         , VP_CLASS_BLOCK_HEADER_PARAM
         , VP_CLASS_APIBLOCK_INPUT_PARAM
         , VP_CLASS_APIBLOCK_PARAM_PLUS_BTN
